@@ -195,20 +195,34 @@ def query_single3(v_par):
     # metric = indexer.metric
     # distfunc = indexer.distfunc
 
+    retk = min(indexer.nitems, topk)
+
+    """
+    Method - 1
+    ----------------
     candidates = {}
     for (wid, wval) in izip(query.nonzero()[1], query.data):
         for (iid, val) in izip(idxs[wid][0], idxs[wid][1]):
             candidates[iid] = candidates.get(iid, 0) + \
                 indexer.dist_core(wval, val)
 
-    retk = min(indexer.nitems, topk)
     candtopk = min(len(candidates), retk)
 
     ranked = np.ones((1, retk)) * -1
     candidates = sorted(candidates.iteritems(), key=operator.itemgetter(1))
     ranked[0, :candtopk] = [item[0] for item in candidates]
+    """
 
-    return (qid, np.array(ranked[:retk]).reshape(1, -1))
+    """
+    Method - 2
+    ----------------
+    """
+    dist = np.zeros(indexer.nitems, np.float)
+    for (wid, wval) in izip(query.nonzero()[1], query.data):
+        dist[idxs[wid][0]] += indexer.dist_core(wval, idxs[wid][1])
+    ranked = nsmallest(retk, dist)
+
+    return (qid, np.array(ranked).reshape(1, -1))
 
 
 class Linear(Indexer):
@@ -555,7 +569,12 @@ class Inverted(Linear):
         logging.info("Adjusting index - $$$$$ (Time costs: %.4fs)!" % toc())
 
     def adjust0(self):
-        pass
+        logging.info("Adjusting index - ^^^^^")
+        tic()
+        for i in xrange(len(self.idxs)):
+            self.idxs[i] = (np.frombuffer(self.idxs[i][0], self.IDX_NPY_TYPE),
+                            np.frombuffer(self.idxs[i][1], self.VAL_NPY_TYPE))
+        logging.info("Adjusting index - $$$$$ (Time costs: %.4fs)!" % toc())
 
     def query_batch(self, query, topk):
         nqrys = query.shape[0]
